@@ -1,9 +1,11 @@
 from pythontools.gui.app import App
 from pythontools.gui.window import MainWindow, Window
+from pythontools.gui.tray import SystemTray
 from pythontools.gui.button import Button
 from pythontools.gui.edits import EditText, EditLine
 from pythontools.gui.label import Label
 from pythontools.gui.listwidget import ListWidget
 from pythontools.gui.menubar import MenuBar
+from pythontools.gui.contextmenu import ContextMenu
 
 from PyQt5.QtCore import Qt
\ No newline at end of file
