@@ -14,8 +14,8 @@ class Object:
         self.obj.setFixedSize(width, height)
         return self
 
-    def setFont(self, name="Time", size=10, bold=False):
-        self.obj.setFont(QtGui.QFont("Time", size, QtGui.QFont.Normal if bold is False else QtGui.QFont.Bold))
+    def setFont(self, name="Times", size=10, bold=False):
+        self.obj.setFont(QtGui.QFont(name, size, QtGui.QFont.Normal if bold is False else QtGui.QFont.Bold))
         return self
 
     def setColor(self, color):
